@@ -2,6 +2,7 @@
 """Bot using the GhostProjectAPI for bulk-checking email addresses.
 
 """
+from time import sleep
 from ...apis import GhostProjectAPI
 
 
@@ -14,6 +15,14 @@ class GhostProjectBot(GhostProjectAPI):
     
     :param kwargs: JSONBot / API keyword-arguments
     """
+    def __search(self, email, backoff=1.0):
+        try:
+            return self.search(email)
+        except:
+            sleep(backoff)
+            backoff *= 1.2
+            return self.__search(email, backoff)
+    
     def check_from_file(self, emails_path):
         """
         Check a list of emails from a given file.
@@ -24,7 +33,7 @@ class GhostProjectBot(GhostProjectAPI):
         data = {}
         with open(emails_path) as f:
             for email in f:
-                data.update(self.search(email.strip()).get('data', {}))
+                data.update(self.__search(email.strip()).get('data', {}))
         return data
     
     def check_from_list(self, *emails):
@@ -36,6 +45,6 @@ class GhostProjectBot(GhostProjectAPI):
         """
         data = {}
         for email in emails:
-            data.update(self.search(email.strip()).get('data', {}))
+            data.update(self.__search(email.strip()).get('data', {}))
         return data
 
