@@ -37,7 +37,7 @@ except ImportError:
 
 
 __all__ = __features__ = ["apicall", "cache", "invalidate", "private", "time_throttle", "API", "APIError", "APIObject",
-                          "SearchAPI"]
+                          "NoResultError", "SearchAPI"]
 
 TIME_THROTTLING = {}
 
@@ -405,6 +405,11 @@ class APIObject(object):
                 a._parent = parent
 
 
+class NoResultError(Exception):
+    def __init__(self, message="No result for the input request"):
+        super(NoResultError, self).__init__(message)
+
+
 class SearchAPI(API):
     """
     SearchAPI class, for managing cache and a search feature relying on multiple backends.
